@@ -263,12 +263,12 @@ class TibberHome:
 
     async def fetch_consumption_data(self):
         """Update consumption info async."""
-        now = dt.datetime.utcnow()
+        now = dt.datetime.utcnow().replace(tzinfo=dt.timezone.utc)
         if self.last_cons_data_timestamp is not None and (
             now - self.last_cons_data_timestamp
         ) < dt.timedelta(hours=24):
             return
-        n_hours = now.hour + now.day * 24
+        n_hours = 30 * 24
 
         consumption = await self.get_historic_data(
             n_hours, resolution=RESOLUTION_HOURLY
